@@ -395,8 +395,26 @@ class TestPath:
         rmtree(expected_dir, ignore_errors=True)
 
     def test_get_filename_extension_from_url(self, fixtureurl):
+        filename = get_filename_from_url(
+            "http://test.com/test.csv", second_last=True
+        )
+        assert filename == "test.csv"
+        filename = get_filename_from_url("http://test.com/test/test.csv", True)
+        assert filename == "test_test.csv"
+        filename = get_filename_from_url(
+            "https://globalhealth5050.org/?_covid-data=dataset-fullvars&_extype=csv",
+            second_last=True,
+        )
+        assert filename == "covid-data-dataset-fullvars-extype-csv"
         filename = get_filename_from_url(fixtureurl)
         assert filename == "test_data.csv"
+        filename = get_filename_from_url(fixtureurl, second_last=True)
+        assert filename == "fixtures_test_data.csv"
         filename, extension = get_filename_extension_from_url(fixtureurl)
         assert filename == "test_data"
         assert extension == ".csv"
+        filename, extension = get_filename_extension_from_url(
+            fixtureurl, second_last=True
+        )
+        assert filename == "fixtures_test_data"
+        assert extension == ".csv"
